@@ -74,8 +74,37 @@ def main():
         default=0,
         help="exit after first num failures or errors.",
     )
+    parser.add_argument("--mode", metavar="mode", help="only run tests with this mode")
     args = parser.parse_args()
 
+    # copy over files from git or as distributed
+    for (git, dist, target) in [
+        ("./mmdebstrap", "/usr/bin/mmdebstrap", "mmdebstrap"),
+        ("./taridshift", "/usr/bin/mmtaridshift", "taridshift"),
+        ("./tarfilter", "/usr/bin/mmtarfilter", "tarfilter"),
+        (
+            "./proxysolver",
+            "/usr/lib/apt/solvers/mmdebstrap-dump-solution",
+            "proxysolver",
+        ),
+        (
+            "./ldconfig.fakechroot",
+            "/usr/libexec/mmdebstrap/ldconfig.fakechroot",
+            "ldconfig.fakechroot",
+        ),
+    ]:
+        if os.path.exists(git):
+            shutil.copy(git, f"shared/{target}")
+        else:
+            shutil.copy(dist, f"shared/{target}")
+    # copy over hooks from git or as distributed
+    if os.path.exists("hooks"):
+        shutil.copytree("hooks", "shared/hooks", dirs_exist_ok=True)
+    else:
+        shutil.copytree(
+            "/usr/share/mmdebstrap/hooks", "shared/hooks", dirs_exist_ok=True
+        )
+
     onlyrun = None
     if len(sys.argv) > 1:
         onlyrun = sys.argv[1]
@@ -118,6 +147,8 @@ def main():
                 if only_dists and dist not in only_dists:
                     continue
                 for mode in modes:
+                    if args.mode and args.mode != mode:
+                        continue
                     for variant in variants:
                         for fmt in formats:
                             skipreason = skip(
@@ -144,6 +175,7 @@ def main():
     starttime = time.time()
     skipped = defaultdict(list)
     failed = []
+    num_success = 0
     for i, (test, name, dist, mode, variant, fmt) in enumerate(tests):
         print(separator, file=sys.stderr)
         print("(%d/%d) %s" % (i + 1, len(tests), name), file=sys.stderr)
@@ -154,7 +186,7 @@ def main():
         if i > 0:
             currenttime = time.time()
             timeleft = timedelta(
-                seconds=(len(tests) - i) * (currenttime - starttime) / i
+                seconds=int((len(tests) - i) * (currenttime - starttime) / i)
             )
             print("time left: %s" % timeleft, file=sys.stderr)
         with open("tests/" + name) as fin, open("shared/test.sh", "w") as fout:
@@ -197,10 +229,11 @@ def main():
             print("result: FAILURE", file=sys.stderr)
         else:
             print("result: SUCCESS", file=sys.stderr)
+            num_success += 1
         if args.maxfail and len(failed) >= args.maxfail:
             break
     print(
-        "successully ran %d tests" % (len(tests) - len(skipped) - len(failed)),
+        "successfully ran %d tests" % num_success,
         file=sys.stderr,
     )
     if skipped:
