@@ -12,9 +12,18 @@ env APT_CONFIG=$MMDEBSTRAP_APT_CONFIG apt-get indextargets --no-release-info \
 	| sed -ne 's/^Repo-URI: file:\/\+//p' \
 	| sort -u \
 	| while read path; do
-		echo "bind-mounting /$path into the chroot" >&2
 		mkdir -p "$rootdir/run/mmdebstrap"
-		mkdir -p "$rootdir/$path"
-		mount -o ro,bind "/$path" "$rootdir/$path"
+		case $MMDEBSTRAP_MODE in
+			root|unshare)
+				echo "bind-mounting /$path into the chroot" >&2
+				mkdir -p "$rootdir/$path"
+				mount -o ro,bind "/$path" "$rootdir/$path"
+				;;
+			*)
+				echo "copying /$path into the chroot" >&2
+				mkdir -p "$rootdir/$(dirname $path)"
+				cp -av "/$path" "$rootdir/$(dirname $path)"
+				;;
+		esac
 		printf '/%s\0' "$path" >> "$rootdir/run/mmdebstrap/file-mirror-automount"
 	done
